@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139, USA.
  * See the COPYING file in this directory.
  *
- * Versions: 1.3 -  FEB 1999
+ * Versions: 1.4 -  July 2001
  */
 
 /*
@@ -30,23 +30,31 @@
 int main (int argc, char *argv[])
 {
    Widget iconwin;
-   struct tag1 app_struct;
    Pixmap pixmap, mask;
    XpmAttributes pix_attributes;
    XpmColorSymbol transparentColor[1] = {{NULL, "none", 0}};
    Pixel bg;
-   AppRes appRes;
                             
    XtResource appRes_desc[] =
    {
       {
-      XmNblink,                       /* Name */
-      XmCBlink,                       /* Class */
+      XmNtzone,                       /* Name */
+      XmCTzone,                       /* Class */
       XmRInt,                         /* Target data type */
       sizeof (int),                   /* size of target type */
-      XtOffsetOf (AppRes, blink),    /* Offset into struct */
+      XtOffsetOf (AppRes, tzone),     /* Offset into struct */
       XtRImmediate,                   /* Default data type */
-      (XtPointer)1                    /* Pointer to default value */
+      (XtPointer) 0                   /* Pointer to default value */
+      },
+
+      {
+      XmNblink,                       /* Same as above */           
+      XmCBlink,                       
+      XmRInt,                         
+      sizeof (int),                   
+      XtOffsetOf (AppRes, blink),     
+      XtRImmediate,                   
+      (XtPointer)1                    
       },
               
       {
@@ -70,7 +78,7 @@ int main (int argc, char *argv[])
       },
               
       {
-      XmNminutes,                        /* Same as above */
+      XmNminutes,                     /* Same as above */
       XmCMinutes,                       
       XmRInt,                         
       sizeof (int),                   
@@ -80,7 +88,7 @@ int main (int argc, char *argv[])
       },
 
       {
-      XmNseconds,                        /* Same as above */
+      XmNseconds,                     /* Same as above */
       XmCSeconds,                       
       XmRInt,                         
       sizeof (int),                   
@@ -88,14 +96,13 @@ int main (int argc, char *argv[])
       XtRImmediate,                   
       (XtPointer)0                    
       },
-           
-           
   };
 
    /*
     * Create clockShell and set some of its properties
     */
-   clock_shell = XtVaAppInitialize ( &(app_struct.app), "Twclock",
+
+   clock_shell = XtVaAppInitialize (&app, "Twclock",
       NULL, 0, &argc, argv, NULL, 
       XmNminHeight, 175,
       XmNminWidth, 175,
@@ -109,7 +116,6 @@ int main (int argc, char *argv[])
       XmNiconName, "TW CLOCK",
       NULL);
 
-
    XtGetApplicationResources (clock_shell, &appRes, appRes_desc,
       XtNumber (appRes_desc), NULL, 0);
 
@@ -140,7 +146,7 @@ int main (int argc, char *argv[])
    /*
     * Build and Realize the rest of the widget tree
     */
-   build_widgets(&app_struct);
+   build_widgets();
    XtRealizeWidget (clock_shell);   
    XtRealizeWidget (iconwin);
 
@@ -155,20 +161,10 @@ int main (int argc, char *argv[])
       XmNiconWindow, XtWindow(iconwin),
       NULL);
 
-   /*
-    * Finish setting up app_struct
-    */
-   
-   app_struct.blink = appRes.blink;
-   app_struct.beep = appRes.beep ;
-   app_struct.flashFlag = 0;
-   app_struct.flashColor = appRes.flashColor;
-   app_struct.minutes = appRes.minutes;
-   app_struct.seconds = appRes.seconds;
    /*
     * Enter the event loop
     */
-   XtAppMainLoop (app_struct.app);
+   XtAppMainLoop (app);
    return (0);
 }
 
